@@ -27,7 +27,7 @@
 
 #define ARROW_CXX_COMPILER_ID "Clang"
 #define ARROW_CXX_COMPILER_VERSION "18.1.8"
-#define ARROW_CXX_COMPILER_FLAGS " -O2 -pipe -Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong -Qunused-arguments -fcolor-diagnostics  -Wa,-mbig-obj -Wall -Wno-unknown-warning-option -Wno-pass-failed -march=armv8-a "
+#define ARROW_CXX_COMPILER_FLAGS " -O2 -pipe -Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong -Wp,-D__USE_MINGW_ANSI_STDIO=1 -Qunused-arguments -fcolor-diagnostics  -Wa,-mbig-obj -Wall -Wno-unknown-warning-option -Wno-pass-failed -march=armv8-a "
 
 #define ARROW_BUILD_TYPE "RELEASE"
 
